@@ -22,7 +22,7 @@ API_BASE_URL = 'https://slack.com/api/{api}'
 
 __all__ = ['Error', 'Response', 'BaseAPI', 'API', 'Auth', 'Users', 'Groups',
            'Channels', 'Chat', 'IM', 'Search', 'Files', 'Stars', 'Emoji',
-           'OAuth', 'Slacker']
+           'Presence', 'OAuth', 'Slacker']
 
 
 class Error(Exception):
@@ -77,6 +77,9 @@ class Auth(BaseAPI):
 
 
 class Users(BaseAPI):
+    def info(self, user):
+        return self.get('users.info', params={'user': user})
+
     def list(self):
         return self.get('users.list')
 
